pub fn describe_symbol_cross_file(
files: &HashMap<PathBuf, String>,
current_path: &Path,
name: &str,
) -> Option<(PathBuf, String)>Expand description
Markdown hover content for name from any project file other than
current_path, plus the path of the file that contributed it. See
find_declaration_cross_file’s doc for the content-ownership-track
shape of files. Returns None if the name is not declared anywhere in
the project.